@@ -8,7 +8,7 @@ use Data::Dumper;
 
 use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $AUTOLOAD);
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 our $AUTOLOAD;
 
 sub new {
@@ -81,9 +81,14 @@ sub set_aiparams {
 sub add_aiparams {
     my $self   = shift;
     my $params = shift;
+    my @keys = ("end_of_speech_timeout", "attention_timeout", "outbound_attention_timeout", "background_file_loops", "background_file_volume", "digit_timeout", "energy_level" );
 
-    while ( my ($k,$v) = each(%{$params}) ) {
-	$self->{_params}->{$k} = $v;
+    while ( my ($k,$v) = each(%{$prompt}) ) {
+	if ( grep { $k } @keys ) {
+            $self->{_prompt}->{$k} = $v + 0;
+	} else {
+            $self->{_prompt}->{$k} = $v;
+	}
     }
 
     return;
@@ -155,9 +160,14 @@ sub set_ailanguage {
 sub set_aipost_prompt {
     my $self       = shift;
     my $postprompt = shift;
+    my @keys = ("confidence", "barge_confidence", "top_p", "temperature", "frequency_penalty", "presence_penalty");
 
-    while ( my ($k,$v) = each(%{$postprompt}) ) {
-	$self->{_post_prompt}->{$k} = $v;
+    while ( my ($k,$v) = each(%{$prompt}) ) {
+	if ( grep { $k } @keys ) {
+            $self->{_prompt}->{$k} = $v + 0;
+	} else {
+            $self->{_prompt}->{$k} = $v;
+	}
     }
 
     return;
@@ -167,9 +177,14 @@ sub set_aipost_prompt {
 sub set_aiprompt {
     my $self   = shift;
     my $prompt = shift;
+    my @keys = ("confidence", "barge_confidence", "top_p", "temperature", "frequency_penalty", "presence_penalty");
 
     while ( my ($k,$v) = each(%{$prompt}) ) {
-	$self->{_prompt}->{$k} = $v;
+	if ( grep { $k } @keys ) {
+            $self->{_prompt}->{$k} = $v + 0;
+	} else {
+            $self->{_prompt}->{$k} = $v;
+	}
     }
 
     return;
